@@ -1,5 +1,4 @@
 package Mira::CLI::Command::init;
-$Mira::CLI::Command::init::VERSION = '00.07.56';
 
 use strict;
 use warnings;
@@ -9,7 +8,6 @@ use App::Cmd::Setup -command;
 use 5.012;
 
 use Cwd;
-use File::Spec;
 use File::Spec::Functions;
 use File::Copy;
 use File::Copy::Recursive qw(dircopy);
@@ -19,7 +17,7 @@ use File::ShareDir ':ALL';
 use utf8;
 binmode STDOUT, ":utf8";
 
-
+use Mira;
 
 my $cwd = cwd;
 
@@ -45,7 +43,6 @@ sub execute {
   my $pensource = $opt->{directory};
 
   {
-my $user = $ENV{'USER'} ? $ENV{'USER'} : 'YOUR_USER_NAME';
   my $config_file = <<"EOCF";
 
 #general 'mira' config, you can make config files for any floor in /config/FLOOR_NAME.yml
@@ -54,12 +51,10 @@ my $user = $ENV{'USER'} ? $ENV{'USER'} : 'YOUR_USER_NAME';
 title: Your Site Tilte
 description: Description of your site
 
-author: $user
+author: $ENV{USER}
 email: your-email\@domain.com
 
-timezone: +00:00
-
-# the base hostname & protocol for your site
+ # the base hostname & protocol for your site
 url: http://localhost:80
 root: /
 static: /static
@@ -68,71 +63,51 @@ imageurl: /static/img
 ## default post permanent link
 permalink: :year/:month/:day/:title/
 
+## Your local Time Zone
+#TimeZone: +00:00
 
-default_markup: markdown
+## Build settings
+default_body_format: markdown
 
 ## number of posts will be show in main index page
-post_num: 5
+post_num: 3
 
 ## number of posts will be show in archives index page
 archive_post_num: 10
 
-## if create new entry without --floor switch with 'mira new', mira use this field
+## if create new entry without --floor switch, mira use this field
 default_floor: blog
 
+## Mira's main directory in your pc
+penurl: $pensource
 
-## template path root is /template
-## if you want use a custom template for examle in /template/Custom_Template_Folde_Name
+
+## template path by root is penurlPATH/template
+## if you want use a custom template for examle in penurlPATH/template/CustomThEM
+## just type custom template folder name
 #> template: Custom_Template_Folde_Name
-template: default-theme
+template: mira-theme-rtl
 
-# default archive fields, like category, tag and ...
-# use for floors which haven't /config/FLOOR.yml or haven't filled or empty lists
+## the fields you want use for archive, like category, tag and ...
+## by default Mira archive date field dont need type it here
+## Mira use this fields by default for the floors which haven't field section
+## in FloorName.yaml, or haven't FloorName.yaml file
+
+#this fields are not allowed: archives, static
 lists:
-  - date
   - categories
   - tags
+  - author
 
-#namespace:
-#  veryverylongarchivename : vlan
-#  learnsections: learn
-#  mybooksButWithALongname: book
-#  aboutThisSite: about
-#  myPersonalDailyDiary: personal
-#  terminalCommandLearning: terminal
-
-social:
- -  icon: twitter
-    name: twitter
-    url: https://twitter.com/Twitter_UserName
-    desc: Follow me on twitter
-    share_url: http://twitter.com/share
-    share_title: ?text=
-    share_link: "&amp;url="
-
- -  icon: github
-    name: github
-    url: https://github.com/GitHub_UserName
-    desc: Fork me on github
-    share_url:
-    share_title:
-    share_link:
-
- -  icon: instagram
-    name: instagram
-    url: https://instagram.com/NAME
-    desc: Follow me
-    share_url:
-    share_title:
-    share_link:
-
- -  icon: facebook-square
-    name: facebook
-    url: https://facebook.com/NAME
-    desc: Follow me
-    share_url:
-    share_title:
-    share_link:
+#url address for long keys or unicode which you want make latin addres for'em
+# for example if you have 'longcategoryname' you can make /category/lcn
+namespace:
+  veryverylongarchivename : vlan
+  آموزش: learn
+  کتاب: book
+  درباره: about
+  شخصی: personal
+  ترمینال: terminal
 
 EOCF
 
@@ -145,7 +120,6 @@ EOCF
 
   make_path catdir($pensource,"content");
   make_path catdir($pensource,"content","blog");
-  make_path catdir($pensource,"config");
 
   my $sharedir = dist_dir('Mira');
 
@@ -173,7 +147,6 @@ EOCF
       catdir($pensource,"statics")
     ) or die $!;
 
-  say "...done!";
 }
 
 
